@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -105,7 +105,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -118,7 +118,7 @@ version 0.0101
   print Dumper [ keys %$songs ];
 
   # show all the song titles:
-  print Dumper [ map{ $songs->{$_}{title} } keys %$songs ];
+  print Dumper [ map { $songs->{$_}{title} } keys %$songs ];
 
 =head1 DESCRIPTION
 
@@ -134,10 +134,11 @@ This module does a few simple things:
 3. It combines the Bach BWV number, song title and key with the data.
 
 The BWV and titles were collected from an old Internet Archive of
-C<jsbchorales.net>.  The keys were computed with a C<music21> program.
-Check out the links in the L</SEE ALSO> section.
+C<jsbchorales.net> and filled-in from C<bach-chorales.com>.  The keys were
+computed with a C<music21> python program and again filled-in from
+C<bach-chorales.com>.  Check out the links in the L</SEE ALSO> section.
 
-See the C<eg/> programs for usage examples.
+See the distribution C<eg/> programs for usage examples.
 
 =head1 ATTRIBUTES
 
@@ -145,20 +146,20 @@ See the C<eg/> programs for usage examples.
 
 The local file where the Bach choral harmony data set resides.
 
-Default: B<dist_dir()>/jsbach_chorals_harmony.data
+Default: C<dist_dir()>/jsbach_chorals_harmony.data
 
 =head2 key_title
 
 The local file where the key signatures and titles for each song are listed by
-BWV number (with a few unfortunate gaps).
+BWV number.
 
-Default: B<dist_dir()>/jsbach_BWV_keys_titles.txt
+Default: C<dist_dir()>/jsbach_BWV_keys_titles.txt
 
 =head1 METHODS
 
 =head2 new()
 
-  $bach = Music::BachChoralHarmony->new(%arguments);
+  $bach = Music::BachChoralHarmony->new();
 
 Create a new C<Music::BachChoralHarmony> object.
 
